import { Button, Icon, Switch } from '@blueprintjs/core'
import { useMemo } from 'react'
import SettingsSection from '../SettingsSection'
import useColorMode from './useColorMode'

const ColorMode = () => {
  const [darkValue, setDark] = useColorMode()
  const dark = useMemo(
    () =>
      darkValue === null
        ? window.matchMedia('(prefers-color-scheme: dark)').matches
        : darkValue,
    [darkValue]
  )

  return (
    <SettingsSection
      title='Color mode'
      subtitle='Change the color mode of the application'
    >
      <Icon icon={dark ? 'moon' : 'circle'} />
      <Switch
        style={{ margin: 0 }}
        checked={dark}
        title='Toggle color mode'
        onChange={() => setDark(!dark)}
      />
      <Button
        icon='reset'
        minimal
        onClick={() => setDark(null)}
        title='Reset to automatic color mode'
      />
    </SettingsSection>
  )
}

export default ColorMode
