import { AnchorButton, Button, ButtonGroup, Popover } from '@blueprintjs/core'
import { css } from '@emotion/css'
import { useHost } from '@inject/graphql/connection/host'
import { downloadLogUrl } from '@inject/shared/config'
import type { FC } from 'react'

const content = css`
  padding: 0.5rem;
`

interface DownloadLogsButtonProps {
  exerciseId: string
}

const DownloadLogsButton: FC<DownloadLogsButtonProps> = ({ exerciseId }) => {
  const host = useHost()

  return (
    <Popover
      content={
        <ButtonGroup className={content} vertical alignText='left'>
          <AnchorButton
            icon='people'
            href={downloadLogUrl(host || '', exerciseId, false)}
            target='_blank'
            rel='noreferrer'
          >
            Standard
          </AnchorButton>
          <AnchorButton
            icon='blocked-person'
            href={downloadLogUrl(host || '', exerciseId, true)}
            target='_blank'
            rel='noreferrer'
          >
            Anonymized
          </AnchorButton>
        </ButtonGroup>
      }
      placement='right'
    >
      <Button icon='download' rightIcon='caret-right'>
        Download logs
      </Button>
    </Popover>
  )
}

export default DownloadLogsButton
