import { Button, ButtonGroup, Card } from '@blueprintjs/core'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import type { FC } from 'react'
import { memo, useCallback } from 'react'
import EmailAddressForm from '../EmailAddressForm'
import EmailTemplateFormDialog from '../EmailTemplateFormDialog'
import EmailTemplates from '../EmailTemplates'
import { deleteEmailAddress } from '../indexeddb/operations'
import type { EmailAddressInfo } from '../indexeddb/types'

interface EmailAddressProps {
  emailAddress: EmailAddressInfo
}

const EmailAddressItem: FC<EmailAddressProps> = ({ emailAddress }) => {
  const { notify } = useNotifyContext()

  const handleDeleteButton = useCallback(
    async (emailAddressInfo: EmailAddressInfo) => {
      try {
        await deleteEmailAddress(emailAddressInfo.id)
      } catch (err) {
        notify(
          `Failed to delete email address '${emailAddressInfo.address}': ${err}`,
          {
            intent: 'danger',
          }
        )
      }
    },
    [notify]
  )

  return (
    <Card style={{ flexDirection: 'column' }}>
      <div
        style={{
          display: 'flex',
          justifyContent: 'space-between',
          alignItems: 'center',
          width: '100%',
          padding: '0rem 1rem 1rem 0',
        }}
      >
        <span style={{ height: '100%', flexGrow: 1 }}>
          {emailAddress.address}
        </span>
        <ButtonGroup>
          <EmailAddressForm
            emailAddressInfo={emailAddress}
            buttonProps={{
              minimal: true,
              icon: 'edit',
              style: { marginRight: '1rem' },
            }}
          />
          <Button
            minimal
            icon='cross'
            onClick={() => handleDeleteButton(emailAddress)}
          />
        </ButtonGroup>
      </div>
      <div style={{ width: '100%', paddingLeft: '2rem' }}>
        <EmailTemplates emailAddressId={Number(emailAddress.id)} />
        <EmailTemplateFormDialog
          emailAddressId={Number(emailAddress.id)}
          buttonProps={{
            minimal: true,
            text: 'Add template',
            alignText: 'left',
            icon: 'plus',
            style: { padding: '1rem', width: '100%' },
          }}
        />
      </div>
    </Card>
  )
}

export default memo(EmailAddressItem)
