import useEditorStorage from '@/editor/useEditorStorage'
import {
  Checkbox,
  InputGroup,
  Label,
  Section,
  SectionCard,
} from '@blueprintjs/core'
import { memo, useEffect, useState } from 'react'

const EmailChannelForm = () => {
  const [config, setConfig] = useEditorStorage()
  const [emailChannelName, setEmailChannelName] = useState(
    config?.emailChannelName || ''
  )
  const [emailBetweenTeams, setEmailBetweenTeams] = useState(
    config?.emailBetweenTeams || false
  )
  const [customEmailSuffix, setCustomEmailSuffix] = useState(
    config?.customEmailSuffix || ''
  )

  useEffect(() => {
    setConfig({
      ...config,
      emailChannelName,
      emailBetweenTeams,
      customEmailSuffix,
    })
  }, [emailChannelName, emailBetweenTeams, customEmailSuffix])

  return (
    <Section title='Email'>
      <SectionCard>
        <Label>
          Custom email channel name
          <InputGroup
            placeholder='Input text'
            value={emailChannelName}
            onChange={e => setEmailChannelName(e.target.value)}
          />
        </Label>
        <Checkbox
          checked={emailBetweenTeams}
          onChange={() => setEmailBetweenTeams(prev => !prev)}
          label={'Enable emails between teams'}
        />
        {emailBetweenTeams && (
          <Label>
            Custom email suffix
            <InputGroup
              placeholder='Input text'
              value={customEmailSuffix}
              onChange={e => setCustomEmailSuffix(e.target.value)}
            />
          </Label>
        )}
      </SectionCard>
    </Section>
  )
}

export default memo(EmailChannelForm)
