import useEditorStorage from '@/editor/useEditorStorage'
import { Checkbox, Label, NumericInput } from '@blueprintjs/core'
import { memo, useEffect, useState, type FC } from 'react'

interface ExerciseDurationFormProps {
  onInputChange: (exerciseDuration: number) => void
}

const ExerciseDurationForm: FC<ExerciseDurationFormProps> = ({
  onInputChange,
}) => {
  const [config, setConfig] = useEditorStorage()
  const [exerciseDuration, setExerciseDuration] = useState(
    config?.exerciseDuration || 0
  )
  const [showExerciseTime, setShowExerciseTime] = useState(
    config?.showExerciseTime || false
  )

  useEffect(() => {
    setConfig({
      ...config,
      exerciseDuration,
      showExerciseTime,
    })
    onInputChange(exerciseDuration)
  }, [exerciseDuration, showExerciseTime])

  return (
    <div>
      <Label>
        Exercise duration in minutes
        <NumericInput
          placeholder='Input number'
          value={exerciseDuration}
          onValueChange={(value: number) => setExerciseDuration(value)}
        />
      </Label>
      <Checkbox
        checked={showExerciseTime}
        onChange={() => setShowExerciseTime(prev => !prev)}
        label={'Show exercise time to trainees?'}
      />
    </div>
  )
}

export default memo(ExerciseDurationForm)
