import { Button, Label, TextArea } from '@blueprintjs/core'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import { useLiveQuery } from 'dexie-react-hooks'
import { memo, useCallback, useEffect, useState, type FC } from 'react'
import {
  addInformationInject,
  getInformationInjectByInjectInfoId,
  updateInformationInject,
} from '../indexeddb/operations'
import type { InformationInject } from '../indexeddb/types'

interface InformationInjectFormProps {
  injectInfoId: number
}

const InformationInjectForm: FC<InformationInjectFormProps> = ({
  injectInfoId,
}) => {
  const informationInject = useLiveQuery(
    () => getInformationInjectByInjectInfoId(injectInfoId),
    [injectInfoId],
    null
  ) as InformationInject

  const { notify } = useNotifyContext()

  const [content, setContent] = useState<string>('')

  useEffect(() => {
    setContent(informationInject?.content || '')
  }, [informationInject])

  const handleUpdateButton = useCallback(
    async (
      newInformationInject: InformationInject | Omit<InformationInject, 'id'>
    ) => {
      try {
        if (informationInject) {
          await updateInformationInject({
            id: informationInject.id,
            ...newInformationInject,
          })
        } else {
          await addInformationInject(newInformationInject)
        }
      } catch (err) {
        notify(`Failed to update information inject: ${err}`, {
          intent: 'danger',
        })
      }
    },
    [notify, informationInject]
  )

  return (
    <div>
      <Label>
        Content
        <TextArea
          value={content}
          style={{
            width: '100%',
            height: '10rem',
            resize: 'none',
            overflowY: 'auto',
          }}
          placeholder='Input text'
          onChange={e => setContent(e.target.value)}
        />
      </Label>
      <Button
        onClick={() =>
          handleUpdateButton({
            injectInfoId,
            content,
          })
        }
        intent='primary'
        icon='edit'
        text='Save changes'
      />
    </div>
  )
}

export default memo(InformationInjectForm)
