import { Divider, NonIdealState } from '@blueprintjs/core'
import { useLiveQuery } from 'dexie-react-hooks'
import { memo, type FC } from 'react'
import InjectForm from '../InjectForm'
import { getInjectInfoById } from '../indexeddb/operations'
import type { InjectInfo } from '../indexeddb/types'
import { InjectType } from '../indexeddb/types'
import EmailInjectForm from './EmailInjectForm'
import InformationInjectForm from './InformationInjectForm'
import QuestionnaireForm from './QuestionnaireForm'

interface InjectSpecificationProps {
  injectInfoId: number
}

const InjectSpecification: FC<InjectSpecificationProps> = ({
  injectInfoId,
}) => {
  const injectInfo = useLiveQuery(
    () => getInjectInfoById(injectInfoId),
    [injectInfoId],
    null
  ) as InjectInfo

  if (!injectInfo) {
    return (
      <NonIdealState
        icon='low-voltage-pole'
        title='No inject'
        description='Inject not found'
      />
    )
  }

  return (
    <div>
      <div>
        <p>Name: {injectInfo.name}</p>
        <p>Description: {injectInfo.description}</p>
        <p>Type: {injectInfo.type}</p>
        <InjectForm
          inject={injectInfo}
          buttonProps={{
            text: 'Edit inject',
            icon: 'edit',
            style: { marginRight: '1rem' },
          }}
        />
      </div>
      <Divider style={{ margin: '1rem 0' }} />
      {injectInfo.type === InjectType.EMAIL && (
        <EmailInjectForm injectInfoId={injectInfoId} />
      )}
      {injectInfo.type === InjectType.INFORMATION && (
        <InformationInjectForm injectInfoId={injectInfoId} />
      )}
      {injectInfo.type === InjectType.QUESTIONNAIRE && (
        <QuestionnaireForm injectInfoId={injectInfoId} />
      )}
    </div>
  )
}

export default memo(InjectSpecification)
