import { db } from '@/editor/indexeddb/db'
import type { InjectInfo } from '@/editor/indexeddb/types'
import { useNavigate } from '@/router'
import { Card, CardList, Icon } from '@blueprintjs/core'
import { useLiveQuery } from 'dexie-react-hooks'
import { memo } from 'react'
import { getInjectIcon } from '../utils'

const InjectsOverview = () => {
  const injectInfos = useLiveQuery(() => db.injectInfos.toArray(), [], [])
  const nav = useNavigate()

  return (
    <CardList>
      {injectInfos?.map((injectInfo: InjectInfo) => (
        <Card
          interactive
          key={injectInfo.id}
          onClick={() =>
            nav(`/editor/create/inject-specification/:injectId`, {
              params: { injectId: injectInfo.id.toString() },
            })
          }
        >
          <Icon
            icon={getInjectIcon(injectInfo)}
            style={{ marginRight: '1rem' }}
          />
          {injectInfo.name}
        </Card>
      ))}
    </CardList>
  )
}

export default memo(InjectsOverview)
