import Checklist from '@/editor/Checklist'
import useEditorStorage from '@/editor/useEditorStorage'
import { memo, useEffect, useState, type FC } from 'react'
import { INTRO_CONDITIONS } from '../utils'

interface IntroductionFormProps {
  onInputChange: (conditions: boolean[]) => void
}

const IntroductionForm: FC<IntroductionFormProps> = ({ onInputChange }) => {
  const [config, setConfig] = useEditorStorage()
  const [conditionChecked, setConditionChecked] = useState(
    config?.introChecked || INTRO_CONDITIONS.map(() => false)
  )

  useEffect(() => {
    setConfig({
      ...config,
      introChecked: conditionChecked,
    })
    onInputChange(conditionChecked)
  }, [conditionChecked])

  return (
    <Checklist
      conditions={INTRO_CONDITIONS}
      initChecked={conditionChecked}
      onInputChange={(conditionChecked: boolean[]) =>
        setConditionChecked(conditionChecked)
      }
    />
  )
}

export default memo(IntroductionForm)
