import { Checkbox, InputGroup, Label, TextArea } from '@blueprintjs/core'
import { memo, type FC } from 'react'
import ToolSelector from '../ToolSelector'

interface ToolResponseFormProps {
  parameter: string
  onParameterChange: (value: string) => void
  content: string
  onContentChange: (value: string) => void
  isRegex: boolean
  onIsRegexChange: (value: boolean) => void
  toolId: number
  onToolIdChange: (value: number) => void
}

const ToolResponseForm: FC<ToolResponseFormProps> = ({
  parameter,
  onParameterChange,
  content,
  onContentChange,
  isRegex,
  onIsRegexChange,
  toolId,
  onToolIdChange,
}) => (
  <div>
    <ToolSelector toolId={toolId} onChange={id => onToolIdChange(id)} />
    <Label>
      Parameter
      <InputGroup
        placeholder='Input text'
        value={parameter}
        onChange={e => onParameterChange(e.target.value)}
      />
    </Label>
    <Checkbox
      label='Is parameter regex?'
      checked={isRegex}
      onChange={e => onIsRegexChange(e.target.checked)}
    />
    <Label>
      Response
      <TextArea
        value={content}
        style={{
          width: '100%',
          height: '10rem',
          resize: 'none',
          overflowY: 'auto',
        }}
        placeholder='Input text'
        onChange={e => onContentChange(e.target.value)}
      />
    </Label>
  </div>
)

export default memo(ToolResponseForm)
