import { Button, ButtonGroup, Card } from '@blueprintjs/core'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import type { FC } from 'react'
import { memo, useCallback } from 'react'
import ToolResponseFormDialog from '../ToolResponseFormDialog'
import { deleteToolResponse } from '../indexeddb/operations'
import type { ToolResponse } from '../indexeddb/types'

interface ToolResponseProps {
  toolResponse: ToolResponse
}

const ToolResponseItem: FC<ToolResponseProps> = ({ toolResponse }) => {
  const { notify } = useNotifyContext()

  const handleDeleteButton = useCallback(
    async (response: ToolResponse) => {
      try {
        await deleteToolResponse(response.id)
      } catch (err) {
        notify(
          `Failed to delete tool response '${response.parameter}': ${err}`,
          {
            intent: 'danger',
          }
        )
      }
    },
    [notify]
  )

  return (
    <Card style={{ display: 'flex', justifyContent: 'space-between' }}>
      <span style={{ height: '100%', flexGrow: 1 }}>
        {toolResponse.parameter}
      </span>
      <ButtonGroup>
        <ToolResponseFormDialog
          response={toolResponse}
          toolId={toolResponse.toolId}
          buttonProps={{
            minimal: true,
            icon: 'edit',
            style: { marginRight: '1rem' },
          }}
        />
        <Button
          minimal
          icon='cross'
          onClick={() => handleDeleteButton(toolResponse)}
        />
      </ButtonGroup>
    </Card>
  )
}

export default memo(ToolResponseItem)
