import { Button, ButtonGroup, Card } from '@blueprintjs/core'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import type { FC } from 'react'
import { memo, useCallback } from 'react'
import ToolForm from '../ToolForm'
import ToolResponseFormDialog from '../ToolResponseFormDialog'
import ToolResponses from '../ToolResponses'
import { deleteTool } from '../indexeddb/operations'
import type { ToolInfo } from '../indexeddb/types'

interface ToolProps {
  tool: ToolInfo
}

const ToolItem: FC<ToolProps> = ({ tool }) => {
  const { notify } = useNotifyContext()

  const handleDeleteButton = useCallback(
    async (toolInfo: ToolInfo) => {
      try {
        await deleteTool(toolInfo.id)
      } catch (err) {
        notify(`Failed to delete tool '${toolInfo.name}': ${err}`, {
          intent: 'danger',
        })
      }
    },
    [notify]
  )

  return (
    <Card style={{ flexDirection: 'column' }}>
      <div
        style={{
          display: 'flex',
          justifyContent: 'space-between',
          alignItems: 'center',
          width: '100%',
          padding: '0rem 1rem 1rem 0',
        }}
      >
        <span style={{ height: '100%', flexGrow: 1 }}>{tool.name}</span>
        <ButtonGroup>
          <ToolForm
            toolInfo={tool}
            buttonProps={{
              minimal: true,
              icon: 'edit',
              style: { marginRight: '1rem' },
            }}
          />
          <Button
            minimal
            icon='cross'
            onClick={() => handleDeleteButton(tool)}
          />
        </ButtonGroup>
      </div>
      <div style={{ width: '100%', paddingLeft: '2rem' }}>
        <ToolResponses toolId={tool.id} />
        <ToolResponseFormDialog
          toolId={tool.id}
          buttonProps={{
            minimal: true,
            text: 'Add tool response',
            alignText: 'left',
            icon: 'plus',
            style: { padding: '1rem', width: '100%' },
          }}
        />
      </div>
    </Card>
  )
}

export default memo(ToolItem)
