import Dexie, { type EntityTable } from 'dexie'
import type {
  EmailAddressInfo,
  EmailInject,
  EmailTemplate,
  InformationInject,
  InjectInfo,
  LearningActivityInfo,
  LearningObjectiveInfo,
  Questionnaire,
  QuestionnaireQuestion,
  ToolInfo,
  ToolResponse,
} from './types'

const dbName = 'EditorDatabase'
const dbVersion = 1

const db = new Dexie(dbName) as Dexie & {
  learningObjectives: EntityTable<LearningObjectiveInfo, 'id'>
  learningActivities: EntityTable<LearningActivityInfo, 'id'>
  injectInfos: EntityTable<InjectInfo, 'id'>
  tools: EntityTable<ToolInfo, 'id'>
  toolResponses: EntityTable<ToolResponse, 'id'>
  emailAddresses: EntityTable<EmailAddressInfo, 'id'>
  emailTemplates: EntityTable<EmailTemplate, 'id'>
  emailInjects: EntityTable<EmailInject, 'id'>
  informationInjects: EntityTable<InformationInject, 'id'>
  questionnaires: EntityTable<Questionnaire, 'id'>
  questionnaireQuestions: EntityTable<QuestionnaireQuestion, 'id'>
}

db.version(dbVersion).stores({
  learningObjectives: '++id, &name',
  learningActivities: '++id, &name, description, type, learningObjectiveId',
  injectInfos: '++id, &name, description, type',
  tools: '++id, &name, tooltipDescription, hint, defaultResponse, category',
  toolResponses:
    '++id, &learningActivityId, toolId, parameter, isRegex, content', // TODO file
  emailAddresses: '++id, address, organization, description, teamVisible',
  emailTemplates: '++id, &learningActivityId, emailAddressId, context, content', // TODO file
  emailInjects:
    '++id, &injectInfoId, emailAddressId, subject, content, extraCopies', // TODO file
  informationInjects: '++id, &injectInfoId, content', // TODO file
  questionnaires: '++id, &injectInfoId, title',
  questionnaireQuestions: '++id, questionnaireId, text, max, correct, labels',
})

export { db }
