import ErrorMessage from '@/components/ErrorMessage'
import { NonIdealState, Spinner } from '@blueprintjs/core'
import { css } from '@emotion/css'
import { useGetTeamLearningObjectives } from '@inject/graphql/queries/GetTeamLearningObjectives.generated'
import Container from '@inject/shared/components/Container'
import notEmpty from '@inject/shared/utils/notEmpty'
import { useMemo, type FC } from 'react'
import LearningObjective from './LearningObjective'

const wrapper = css`
  display: flex;
  flex-direction: column;
  gap: 1rem;
  padding: 1rem 0;
`

interface LearningObjectivesProps {
  teamId: string
}

const LearningObjectives: FC<LearningObjectivesProps> = ({ teamId }) => {
  const { data, loading, error } = useGetTeamLearningObjectives({
    variables: { teamId },
  })
  const objectives = useMemo(
    () => data?.teamLearningObjectives?.filter(notEmpty) ?? [],
    [data]
  )

  if (loading) {
    return <Spinner />
  } else if (error) {
    return (
      <ErrorMessage>
        <h1>Error occurred!</h1>
        <p>{error.message}</p>
      </ErrorMessage>
    )
  } else if (!data || !data.teamLearningObjectives) {
    return (
      <NonIdealState
        icon='low-voltage-pole'
        title='No data'
        description='Please wait for the data to come in'
      />
    )
  }

  if (objectives.length === 0) {
    return (
      <NonIdealState
        icon='low-voltage-pole'
        title='No learning objectives'
        description='There are no learning objectives to display'
      />
    )
  }

  return (
    <Container className={wrapper}>
      {objectives.map(objective => (
        <LearningObjective
          key={objective.id}
          objective={objective}
          teamId={teamId}
        />
      ))}
    </Container>
  )
}

export default LearningObjectives
