import type { ValueType } from '@/components/SortableTable/typing'
import type { User } from '@inject/graphql/fragments/User.generated'
import type { AuthGroup } from '@inject/graphql/types'
import type { Dispatch, SetStateAction } from 'react'

export const AUTH_GROUPS: AuthGroup[] = ['ADMIN', 'INSTRUCTOR', 'TRAINEE']

export type Filter<T> = {
  selected: T
  setSelected: Dispatch<SetStateAction<T>>
}

export type Active = { active: boolean; inactive: boolean }

export interface UserProperty {
  name: string
  display?: boolean
  getValue: (element: User) => ValueType
}

export const USER_PROPERTIES: UserProperty[] = [
  {
    name: 'ID',
    display: false,
    getValue: (user: User) => user.id,
  },
  {
    name: 'Username',
    display: true,
    getValue: (user: User) => user.username,
  },
  {
    name: 'First name',
    display: true,
    getValue: (user: User) => user.firstName,
  },
  {
    name: 'Last name',
    display: true,
    getValue: (user: User) => user.lastName,
  },
  {
    name: 'Group',
    display: true,
    getValue: (user: User) => user.group,
  },
  {
    name: 'Active',
    display: true,
    getValue: (user: User) => user.isActive,
  },
  {
    name: 'Imported',
    display: false,
    getValue: (user: User) => user.isImported,
  },
  {
    name: 'Created at',
    display: false,
    getValue: (user: User) => new Date(user.dateJoined),
  },
  {
    name: 'Last login',
    display: false,
    getValue: (user: User) =>
      user.lastLogin ? new Date(user.lastLogin) : null,
  },
  {
    name: 'Tags',
    display: true,
    getValue: (user: User) => (user.tags || []).map(tag => tag.name).join(', '),
  },
]
