import ExitButton from '@/components/ExitButton'
import type { Section } from '@/components/Sidebar'
import Sidebar from '@/components/Sidebar'
import useHideButton from '@/components/Sidebar/useHideButton'
import Navbar from '@/editor/Navbar'
import NotificationDropdown from '@inject/shared/notification/NotificationDropdown'
import type { FC, PropsWithChildren } from 'react'
import { memo, useMemo } from 'react'

const EditorView: FC<PropsWithChildren> = ({ children }) => {
  const { hide: hideLeftBar, node: hideButton } = useHideButton()

  const sections: Section[] = useMemo(
    () => [
      {
        name: 'Options',
        node: (
          <>
            {hideButton}
            <NotificationDropdown hideLabel={hideLeftBar} fill />
            <ExitButton hideLabel={hideLeftBar} />
          </>
        ),
      },
      {
        name: 'Steps',
        node: !hideLeftBar && <Navbar />,
      },
    ],
    [hideButton, hideLeftBar]
  )

  return (
    <>
      <div style={{ height: '100%', display: 'flex' }}>
        <Sidebar
          position='left'
          sections={sections}
          hideNames={hideLeftBar}
          showLogo
        />

        <div style={{ overflow: 'auto', flex: 1 }}>{children}</div>
      </div>
    </>
  )
}

export default memo(EditorView)
